.. _getting_started_tutorial:

===============
Getting Started
===============

We're about to walk through the basic structure and functionality of ``pseudopeople``.

..
   Update this file.

Instead, we'll first walk through some tips and tools that will help us
keep things organized and make collaboration easy. It will also enable
us to run simulations from the command line. This is vital for any
serious simulation work.

.. contents::
   :depth: 1
   :local:
   :backlinks: none

Organizing our work
-------------------

Instead of storing our work in one or several python files, we'll store it
in a python package. A `python package`__ is a bundle of structured python
code that a user can install. This is the key to making python's ``import``
statement work.



__ https://docs.python.org/3/tutorial/modules.html#packages

Version control
---------------


Making an environment
---------------------

The next thing we'll do is set up a programming environment. This is like
a clean room for your code and all the code it depends on. It helps

Installing your library
-----------------------

Next steps
----------
